@@ -333,6 +333,7 @@ index(singleton_heap(?,?,?), heaps, heaps).
 index(help, prolog_help, help).
 index(help(?), prolog_help, help).
 index(apropos(?), prolog_help, help).
+index(help_text(?,?), prolog_help, help).
 index(load_hotfixes(?), prolog_hotfix, hotfix).
 index(incr_assert(:), increval, increval).
 index(incr_asserta(:), increval, increval).
@@ -922,7 +923,6 @@ index(tnodebug(?), thread_util, threadutil).
 index(tprofile(?), thread_util, threadutil).
 index(tbacktrace(?), thread_util, threadutil).
 index(tbacktrace(?,?), thread_util, threadutil).
-index(thread_run_interactor, thread_util, threadutil).
 index(interactor, thread_util, threadutil).
 index(interactor(?), thread_util, threadutil).
 index(tty_clear, tty, tty).
